@@ -1,5 +1,5 @@
 import copy
-import json
+import simplejson
 import requests
 import warnings
 
@@ -106,7 +106,11 @@ class Connection(object):
     return self._handle_response(requests.post(url, data=request_params))
 
   def _handle_response(self, response):
-    response_json = response.json()
+    try:
+      response_json = response.json()
+    except simplejson.decoder.JSONDecodeError:
+      raise ApiException({'message': response.text}, response.status_code)
+
     if 200 <= response.status_code <= 299:
       response = response_json.get('response')
       return response
@@ -128,13 +132,13 @@ class Connection(object):
 
     def serialize(value):
       if isinstance(value, dict):
-        return json.dumps(value)
+        return simplejson.dumps(value)
       return str(value)
 
     return dict((
       (key, serialize(self._to_api_value(value)))
       for key, value
-      in req_params.iteritems()
+      in req_params.items()
       if value is not None
     ))
 
